==> config-service-jar-2.1-sources.jar: org/nhindirect/config/processor/BundleRefreshProcessor.java <==
/* 
Copyright (c) 2010, NHIN Direct Project
All rights reserved.

Authors:
   Greg Meyer      gm2552@cerner.com
 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
in the documentation and/or other materials provided with the distribution.  Neither the name of the The NHIN Direct Project (nhindirect.org). 
nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.nhindirect.config.processor;

import org.nhindirect.config.store.TrustBundle;

/**
 * Interface for refreshing the anchors within a bundle.  This interface is typically
 * incorporated as part of enterprise application flow such as an Apache Camel route
 * @author Greg Meyer
 * @since 1.3
 */
public interface BundleRefreshProcessor 
{
	/**
	 * Refreshes the set of anchors within a bundle.  The bundle is downloaded from the bundle's URL, validated for authenticity if the bundle is signed
	 * and a signing certificate has been configured, and the anchors are updated in the store.  If the bundle has not changed (which can be checked
	 * using the bundle checksum), then the anchors in the bundle may not be updated.
	 * @param bundle The bundle that will be updated.
	 */
	public void refreshBundle(TrustBundle bundle);	
}

==> config-service-jar-8.0.4-sources.jar: org/nhindirect/config/processor/BundleRefreshProcessor.java <==
/* 
Copyright (c) 2010, NHIN Direct Project
All rights reserved.

Authors:
   Greg Meyer      gm2552@cerner.com
 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
in the documentation and/or other materials provided with the distribution.  Neither the name of the The NHIN Direct Project (nhindirect.org). 
nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.nhindirect.config.processor;

import org.nhindirect.config.store.TrustBundle;

import reactor.core.publisher.Mono;

/**
 * Interface for refreshing the anchors within a bundle.  This interface is typically
 * incorporated as part of enterprise application flow such as an Apache Camel route
 * @author Greg Meyer
 * @since 1.3
 */
public interface BundleRefreshProcessor 
{
	/**
	 * Refreshes the set of anchors within a bundle.  The bundle is downloaded from the bundle's URL, validated for authenticity if the bundle is signed
	 * and a signing certificate has been configured, and the anchors are updated in the store.  If the bundle has not changed (which can be checked
	 * using the bundle checksum), then the anchors in the bundle may not be updated.
	 * @param bundle The bundle that will be updated.
	 */
	public Mono<?> refreshBundle(TrustBundle bundle);	
}
